Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorrschnekenbu2009-06-25 08:15:16 +0000
committerrschnekenbu2009-06-25 08:15:16 +0000
commitcfa98ec8159e672ff9c2492ac18a859a25e72712 (patch)
tree3e387808fb8bec745d98a7e1b89fba117fb3783f /plugins/developer/org.eclipse.papyrus.gmfgenextension
parentc4641499825658cb470c0b48ecee5400cc15eb63 (diff)
downloadorg.eclipse.papyrus-cfa98ec8159e672ff9c2492ac18a859a25e72712.tar.gz
org.eclipse.papyrus-cfa98ec8159e672ff9c2492ac18a859a25e72712.tar.xz
org.eclipse.papyrus-cfa98ec8159e672ff9c2492ac18a859a25e72712.zip
bug 271472 being fixed: support of stereotypes for the edge. This is only done for usage representation in this commit. Following commit will update the whole class diagram
Diffstat (limited to 'plugins/developer/org.eclipse.papyrus.gmfgenextension')
-rw-r--r--plugins/developer/org.eclipse.papyrus.gmfgenextension/model/papyrusGmfgenExtension.ecore8
-rw-r--r--plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/ExtendedGenView.java (renamed from plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/ExtendedGenNode.java)60
-rw-r--r--plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/PapyrusgmfgenextensionFactory.java6
-rw-r--r--plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/PapyrusgmfgenextensionPackage.java114
-rw-r--r--plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/impl/ExtendedGenViewImpl.java (renamed from plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/impl/ExtendedGenNodeImpl.java)141
-rw-r--r--plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/impl/PapyrusExtensionRootNodeImpl.java79
-rw-r--r--plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/impl/PapyrusgmfgenextensionFactoryImpl.java8
-rw-r--r--plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/impl/PapyrusgmfgenextensionPackageImpl.java423
-rw-r--r--plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/util/PapyrusgmfgenextensionAdapterFactory.java10
-rw-r--r--plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/util/PapyrusgmfgenextensionSwitch.java14
10 files changed, 431 insertions, 432 deletions
diff --git a/plugins/developer/org.eclipse.papyrus.gmfgenextension/model/papyrusGmfgenExtension.ecore b/plugins/developer/org.eclipse.papyrus.gmfgenextension/model/papyrusGmfgenExtension.ecore
index afc3c04cabb..7e0d489311f 100644
--- a/plugins/developer/org.eclipse.papyrus.gmfgenextension/model/papyrusGmfgenExtension.ecore
+++ b/plugins/developer/org.eclipse.papyrus.gmfgenextension/model/papyrusGmfgenExtension.ecore
@@ -3,15 +3,15 @@
xmlns:xmi="http://www.omg.org/XMI" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
xmlns:ecore="http://www.eclipse.org/emf/2002/Ecore" name="papyrusgmfgenextension"
nsURI="http://www.eclipse.org/papyrus/2009/papyrusgmfgenextension" nsPrefix="papyrusgmfgenextension">
- <eClassifiers xsi:type="ecore:EClass" name="ExtendedGenNode" eSuperTypes="#//CommentedElement">
+ <eClassifiers xsi:type="ecore:EClass" name="ExtendedGenView" eSuperTypes="#//CommentedElement">
<eAnnotations source="http://www.eclipse.org/emf/2002/GenModel">
- <details key="documentation" value="This element is always linked to a genNode (topLevel, or child)&#xD;&#xA;Used set if an editPart is abstract.&#xD;&#xA;SuperGenNodes is a list of all superEditPart.&#xD;&#xA;&#xD;&#xA;Thanks to this, it is possible to factorize code and to decrease the number of generated classes."/>
+ <details key="documentation" value="This element is always linked to a genView (topLevel, or child)&#xD;&#xA;Used set if an editPart is abstract.&#xD;&#xA;SuperGenViews is a list of all superEditPart.&#xD;&#xA;&#xD;&#xA;Thanks to this, it is possible to factorize code and to decrease the number of generated classes."/>
</eAnnotations>
- <eStructuralFeatures xsi:type="ecore:EReference" name="genNode" ordered="false"
+ <eStructuralFeatures xsi:type="ecore:EReference" name="genView" ordered="false"
unique="false" lowerBound="1" upperBound="-1" eType="ecore:EClass platform:/plugin/org.eclipse.gmf.codegen/models/gmfgen.ecore#//GenCommonBase"/>
<eStructuralFeatures xsi:type="ecore:EAttribute" name="isAbstract" ordered="false"
unique="false" lowerBound="1" eType="ecore:EDataType http://www.eclipse.org/emf/2002/Ecore#//EBoolean"/>
- <eStructuralFeatures xsi:type="ecore:EReference" name="superGenNodes" ordered="false"
+ <eStructuralFeatures xsi:type="ecore:EReference" name="superGenViews" ordered="false"
unique="false" upperBound="-1" eType="ecore:EClass platform:/plugin/org.eclipse.gmf.codegen/models/gmfgen.ecore#//GenCommonBase"/>
<eStructuralFeatures xsi:type="ecore:EReference" name="propRefreshHook" ordered="false"
unique="false" eType="#//PropertyRefreshHook" containment="true"/>
diff --git a/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/impl/PapyrusExtensionRootNodeImpl.java b/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/impl/PapyrusExtensionRootNodeImpl.java
index 6c46c7ae927..6135e9e26ad 100644
--- a/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/impl/PapyrusExtensionRootNodeImpl.java
+++ b/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/impl/PapyrusExtensionRootNodeImpl.java
@@ -9,38 +9,31 @@ package org.eclipse.papyrus.papyrusgmfgenextension.impl;
import java.util.Collection;
import org.eclipse.emf.common.notify.NotificationChain;
-
import org.eclipse.emf.common.util.EList;
-
import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.InternalEObject;
-
import org.eclipse.emf.ecore.util.EObjectContainmentEList;
import org.eclipse.emf.ecore.util.InternalEList;
-
import org.eclipse.papyrus.papyrusgmfgenextension.CommentedElement;
-import org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode;
import org.eclipse.papyrus.papyrusgmfgenextension.PapyrusExtensionRootNode;
import org.eclipse.papyrus.papyrusgmfgenextension.PapyrusgmfgenextensionPackage;
/**
- * <!-- begin-user-doc -->
- * An implementation of the model object '<em><b>Papyrus Extension Root Node</b></em>'.
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> An implementation of the model object '<em><b>Papyrus Extension Root Node</b></em>'. <!-- end-user-doc -->
* <p>
* The following features are implemented:
* <ul>
- * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.PapyrusExtensionRootNodeImpl#getExtensionNodes <em>Extension Nodes</em>}</li>
+ * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.PapyrusExtensionRootNodeImpl#getExtensionNodes <em>Extension Nodes</em>}</li>
* </ul>
* </p>
- *
+ *
* @generated
*/
public class PapyrusExtensionRootNodeImpl extends CommentedElementImpl implements PapyrusExtensionRootNode {
+
/**
- * The cached value of the '{@link #getExtensionNodes() <em>Extension Nodes</em>}' containment reference list.
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * The cached value of the '{@link #getExtensionNodes() <em>Extension Nodes</em>}' containment reference list. <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @see #getExtensionNodes()
* @generated
* @ordered
@@ -48,8 +41,8 @@ public class PapyrusExtensionRootNodeImpl extends CommentedElementImpl implement
protected EList<CommentedElement> extensionNodes;
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
protected PapyrusExtensionRootNodeImpl() {
@@ -57,8 +50,8 @@ public class PapyrusExtensionRootNodeImpl extends CommentedElementImpl implement
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
@Override
@@ -67,8 +60,8 @@ public class PapyrusExtensionRootNodeImpl extends CommentedElementImpl implement
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EList<CommentedElement> getExtensionNodes() {
@@ -79,77 +72,77 @@ public class PapyrusExtensionRootNodeImpl extends CommentedElementImpl implement
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
@Override
public NotificationChain eInverseRemove(InternalEObject otherEnd, int featureID, NotificationChain msgs) {
switch (featureID) {
- case PapyrusgmfgenextensionPackage.PAPYRUS_EXTENSION_ROOT_NODE__EXTENSION_NODES:
- return ((InternalEList<?>)getExtensionNodes()).basicRemove(otherEnd, msgs);
+ case PapyrusgmfgenextensionPackage.PAPYRUS_EXTENSION_ROOT_NODE__EXTENSION_NODES:
+ return ((InternalEList<?>) getExtensionNodes()).basicRemove(otherEnd, msgs);
}
return super.eInverseRemove(otherEnd, featureID, msgs);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
@Override
public Object eGet(int featureID, boolean resolve, boolean coreType) {
switch (featureID) {
- case PapyrusgmfgenextensionPackage.PAPYRUS_EXTENSION_ROOT_NODE__EXTENSION_NODES:
- return getExtensionNodes();
+ case PapyrusgmfgenextensionPackage.PAPYRUS_EXTENSION_ROOT_NODE__EXTENSION_NODES:
+ return getExtensionNodes();
}
return super.eGet(featureID, resolve, coreType);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
@SuppressWarnings("unchecked")
@Override
public void eSet(int featureID, Object newValue) {
switch (featureID) {
- case PapyrusgmfgenextensionPackage.PAPYRUS_EXTENSION_ROOT_NODE__EXTENSION_NODES:
- getExtensionNodes().clear();
- getExtensionNodes().addAll((Collection<? extends CommentedElement>)newValue);
- return;
+ case PapyrusgmfgenextensionPackage.PAPYRUS_EXTENSION_ROOT_NODE__EXTENSION_NODES:
+ getExtensionNodes().clear();
+ getExtensionNodes().addAll((Collection<? extends CommentedElement>) newValue);
+ return;
}
super.eSet(featureID, newValue);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
@Override
public void eUnset(int featureID) {
switch (featureID) {
- case PapyrusgmfgenextensionPackage.PAPYRUS_EXTENSION_ROOT_NODE__EXTENSION_NODES:
- getExtensionNodes().clear();
- return;
+ case PapyrusgmfgenextensionPackage.PAPYRUS_EXTENSION_ROOT_NODE__EXTENSION_NODES:
+ getExtensionNodes().clear();
+ return;
}
super.eUnset(featureID);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
@Override
public boolean eIsSet(int featureID) {
switch (featureID) {
- case PapyrusgmfgenextensionPackage.PAPYRUS_EXTENSION_ROOT_NODE__EXTENSION_NODES:
- return extensionNodes != null && !extensionNodes.isEmpty();
+ case PapyrusgmfgenextensionPackage.PAPYRUS_EXTENSION_ROOT_NODE__EXTENSION_NODES:
+ return extensionNodes != null && !extensionNodes.isEmpty();
}
return super.eIsSet(featureID);
}
-} //PapyrusExtensionRootNodeImpl
+} // PapyrusExtensionRootNodeImpl
diff --git a/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/impl/PapyrusgmfgenextensionFactoryImpl.java b/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/impl/PapyrusgmfgenextensionFactoryImpl.java
index 5af72e18e82..b5165f25a5a 100644
--- a/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/impl/PapyrusgmfgenextensionFactoryImpl.java
+++ b/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/impl/PapyrusgmfgenextensionFactoryImpl.java
@@ -60,7 +60,7 @@ public class PapyrusgmfgenextensionFactoryImpl extends EFactoryImpl implements P
@Override
public EObject create(EClass eClass) {
switch (eClass.getClassifierID()) {
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE: return createExtendedGenNode();
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW: return createExtendedGenView();
case PapyrusgmfgenextensionPackage.COMMENTED_ELEMENT: return createCommentedElement();
case PapyrusgmfgenextensionPackage.PROPERTY_REFRESH_HOOK: return createPropertyRefreshHook();
case PapyrusgmfgenextensionPackage.EXTERNAL_HOOK: return createExternalHook();
@@ -81,9 +81,9 @@ public class PapyrusgmfgenextensionFactoryImpl extends EFactoryImpl implements P
* <!-- end-user-doc -->
* @generated
*/
- public ExtendedGenNode createExtendedGenNode() {
- ExtendedGenNodeImpl extendedGenNode = new ExtendedGenNodeImpl();
- return extendedGenNode;
+ public ExtendedGenView createExtendedGenView() {
+ ExtendedGenViewImpl extendedGenView = new ExtendedGenViewImpl();
+ return extendedGenView;
}
/**
diff --git a/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/impl/PapyrusgmfgenextensionPackageImpl.java b/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/impl/PapyrusgmfgenextensionPackageImpl.java
index dffe6683013..7e7776fca77 100644
--- a/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/impl/PapyrusgmfgenextensionPackageImpl.java
+++ b/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/impl/PapyrusgmfgenextensionPackageImpl.java
@@ -7,22 +7,18 @@
package org.eclipse.papyrus.papyrusgmfgenextension.impl;
import org.eclipse.emf.codegen.ecore.genmodel.GenModelPackage;
-
import org.eclipse.emf.ecore.EAttribute;
import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EPackage;
import org.eclipse.emf.ecore.EReference;
import org.eclipse.emf.ecore.EcorePackage;
-
import org.eclipse.emf.ecore.impl.EPackageImpl;
-
import org.eclipse.gmf.codegen.gmfgen.GMFGenPackage;
-
import org.eclipse.papyrus.papyrusgmfgenextension.AlternateCanvas;
import org.eclipse.papyrus.papyrusgmfgenextension.AlternateGenLink;
import org.eclipse.papyrus.papyrusgmfgenextension.AlternateGenTopLevelNode;
import org.eclipse.papyrus.papyrusgmfgenextension.CommentedElement;
-import org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode;
+import org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView;
import org.eclipse.papyrus.papyrusgmfgenextension.ExternalHook;
import org.eclipse.papyrus.papyrusgmfgenextension.MutatingCanvas;
import org.eclipse.papyrus.papyrusgmfgenextension.OwnedEditpart;
@@ -33,99 +29,95 @@ import org.eclipse.papyrus.papyrusgmfgenextension.PropertyRefreshHook;
import org.eclipse.papyrus.papyrusgmfgenextension.SpecificLocator;
/**
- * <!-- begin-user-doc -->
- * An implementation of the model <b>Package</b>.
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> An implementation of the model <b>Package</b>. <!-- end-user-doc -->
+ *
* @generated
*/
public class PapyrusgmfgenextensionPackageImpl extends EPackageImpl implements PapyrusgmfgenextensionPackage {
+
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
- private EClass extendedGenNodeEClass = null;
+ private EClass extendedGenViewEClass = null;
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
private EClass commentedElementEClass = null;
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
private EClass propertyRefreshHookEClass = null;
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
private EClass externalHookEClass = null;
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
private EClass specificLocatorEClass = null;
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
private EClass papyrusExtensionRootNodeEClass = null;
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
private EClass alternateCanvasEClass = null;
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
private EClass alternateGenTopLevelNodeEClass = null;
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
private EClass alternateGenLinkEClass = null;
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
private EClass mutatingCanvasEClass = null;
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
private EClass ownedEditpartEClass = null;
/**
- * Creates an instance of the model <b>Package</b>, registered with
- * {@link org.eclipse.emf.ecore.EPackage.Registry EPackage.Registry} by the package
- * package URI value.
- * <p>Note: the correct way to create the package is via the static
- * factory method {@link #init init()}, which also performs
- * initialization of the package, or returns the registered package,
- * if one already exists.
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * Creates an instance of the model <b>Package</b>, registered with {@link org.eclipse.emf.ecore.EPackage.Registry EPackage.Registry} by the package package URI value.
+ * <p>
+ * Note: the correct way to create the package is via the static factory method {@link #init init()}, which also performs initialization of the package, or returns the registered package, if one
+ * already exists. <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @see org.eclipse.emf.ecore.EPackage.Registry
* @see org.eclipse.papyrus.papyrusgmfgenextension.PapyrusgmfgenextensionPackage#eNS_URI
* @see #init()
@@ -136,39 +128,32 @@ public class PapyrusgmfgenextensionPackageImpl extends EPackageImpl implements P
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
private static boolean isInited = false;
/**
- * Creates, registers, and initializes the <b>Package</b> for this
- * model, and for any others upon which it depends. Simple
- * dependencies are satisfied by calling this method on all
- * dependent packages before doing anything else. This method drives
- * initialization for interdependent packages directly, in parallel
- * with this package, itself.
- * <p>Of this package and its interdependencies, all packages which
- * have not yet been registered by their URI values are first created
- * and registered. The packages are then initialized in two steps:
- * meta-model objects for all of the packages are created before any
- * are initialized, since one package's meta-model objects may refer to
- * those of another.
- * <p>Invocation of this method will not affect any packages that have
- * already been initialized.
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * Creates, registers, and initializes the <b>Package</b> for this model, and for any others upon which it depends.
+ *
+ * <p>
+ * This method is used to initialize {@link PapyrusgmfgenextensionPackage#eINSTANCE} when that field is accessed. Clients should not invoke it directly. Instead, they should simply access that
+ * field to obtain the package. <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @see #eNS_URI
* @see #createPackageContents()
* @see #initializePackageContents()
* @generated
*/
public static PapyrusgmfgenextensionPackage init() {
- if (isInited) return (PapyrusgmfgenextensionPackage)EPackage.Registry.INSTANCE.getEPackage(PapyrusgmfgenextensionPackage.eNS_URI);
+ if (isInited)
+ return (PapyrusgmfgenextensionPackage) EPackage.Registry.INSTANCE.getEPackage(PapyrusgmfgenextensionPackage.eNS_URI);
// Obtain or create and register package
- PapyrusgmfgenextensionPackageImpl thePapyrusgmfgenextensionPackage = (PapyrusgmfgenextensionPackageImpl)(EPackage.Registry.INSTANCE.getEPackage(eNS_URI) instanceof PapyrusgmfgenextensionPackageImpl ? EPackage.Registry.INSTANCE.getEPackage(eNS_URI) : new PapyrusgmfgenextensionPackageImpl());
+ PapyrusgmfgenextensionPackageImpl thePapyrusgmfgenextensionPackage = (PapyrusgmfgenextensionPackageImpl) (EPackage.Registry.INSTANCE.get(eNS_URI) instanceof PapyrusgmfgenextensionPackageImpl ? EPackage.Registry.INSTANCE
+ .get(eNS_URI)
+ : new PapyrusgmfgenextensionPackageImpl());
isInited = true;
@@ -184,75 +169,77 @@ public class PapyrusgmfgenextensionPackageImpl extends EPackageImpl implements P
// Mark meta-data to indicate it can't be changed
thePapyrusgmfgenextensionPackage.freeze();
+ // Update the registry and return the package
+ EPackage.Registry.INSTANCE.put(PapyrusgmfgenextensionPackage.eNS_URI, thePapyrusgmfgenextensionPackage);
return thePapyrusgmfgenextensionPackage;
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
- public EClass getExtendedGenNode() {
- return extendedGenNodeEClass;
+ public EClass getExtendedGenView() {
+ return extendedGenViewEClass;
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
- public EReference getExtendedGenNode_GenNode() {
- return (EReference)extendedGenNodeEClass.getEStructuralFeatures().get(0);
+ public EReference getExtendedGenView_GenView() {
+ return (EReference) extendedGenViewEClass.getEStructuralFeatures().get(0);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
- public EAttribute getExtendedGenNode_IsAbstract() {
- return (EAttribute)extendedGenNodeEClass.getEStructuralFeatures().get(1);
+ public EAttribute getExtendedGenView_IsAbstract() {
+ return (EAttribute) extendedGenViewEClass.getEStructuralFeatures().get(1);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
- public EReference getExtendedGenNode_SuperGenNodes() {
- return (EReference)extendedGenNodeEClass.getEStructuralFeatures().get(2);
+ public EReference getExtendedGenView_SuperGenViews() {
+ return (EReference) extendedGenViewEClass.getEStructuralFeatures().get(2);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
- public EReference getExtendedGenNode_PropRefreshHook() {
- return (EReference)extendedGenNodeEClass.getEStructuralFeatures().get(3);
+ public EReference getExtendedGenView_PropRefreshHook() {
+ return (EReference) extendedGenViewEClass.getEStructuralFeatures().get(3);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
- public EAttribute getExtendedGenNode_Name() {
- return (EAttribute)extendedGenNodeEClass.getEStructuralFeatures().get(4);
+ public EAttribute getExtendedGenView_Name() {
+ return (EAttribute) extendedGenViewEClass.getEStructuralFeatures().get(4);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
- public EAttribute getExtendedGenNode_SuperOwnedEditPart() {
- return (EAttribute)extendedGenNodeEClass.getEStructuralFeatures().get(5);
+ public EAttribute getExtendedGenView_SuperOwnedEditPart() {
+ return (EAttribute) extendedGenViewEClass.getEStructuralFeatures().get(5);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EClass getCommentedElement() {
@@ -260,17 +247,17 @@ public class PapyrusgmfgenextensionPackageImpl extends EPackageImpl implements P
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EAttribute getCommentedElement_Comment() {
- return (EAttribute)commentedElementEClass.getEStructuralFeatures().get(0);
+ return (EAttribute) commentedElementEClass.getEStructuralFeatures().get(0);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EClass getPropertyRefreshHook() {
@@ -278,26 +265,26 @@ public class PapyrusgmfgenextensionPackageImpl extends EPackageImpl implements P
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EAttribute getPropertyRefreshHook_TriggeringCondition() {
- return (EAttribute)propertyRefreshHookEClass.getEStructuralFeatures().get(0);
+ return (EAttribute) propertyRefreshHookEClass.getEStructuralFeatures().get(0);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EAttribute getPropertyRefreshHook_Action() {
- return (EAttribute)propertyRefreshHookEClass.getEStructuralFeatures().get(1);
+ return (EAttribute) propertyRefreshHookEClass.getEStructuralFeatures().get(1);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EClass getExternalHook() {
@@ -305,17 +292,17 @@ public class PapyrusgmfgenextensionPackageImpl extends EPackageImpl implements P
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EAttribute getExternalHook_Classpath() {
- return (EAttribute)externalHookEClass.getEStructuralFeatures().get(0);
+ return (EAttribute) externalHookEClass.getEStructuralFeatures().get(0);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EClass getSpecificLocator() {
@@ -323,17 +310,17 @@ public class PapyrusgmfgenextensionPackageImpl extends EPackageImpl implements P
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EReference getSpecificLocator_GenChildSideAffixedNode() {
- return (EReference)specificLocatorEClass.getEStructuralFeatures().get(0);
+ return (EReference) specificLocatorEClass.getEStructuralFeatures().get(0);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EClass getPapyrusExtensionRootNode() {
@@ -341,17 +328,17 @@ public class PapyrusgmfgenextensionPackageImpl extends EPackageImpl implements P
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EReference getPapyrusExtensionRootNode_ExtensionNodes() {
- return (EReference)papyrusExtensionRootNodeEClass.getEStructuralFeatures().get(0);
+ return (EReference) papyrusExtensionRootNodeEClass.getEStructuralFeatures().get(0);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EClass getAlternateCanvas() {
@@ -359,44 +346,44 @@ public class PapyrusgmfgenextensionPackageImpl extends EPackageImpl implements P
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EReference getAlternateCanvas_DomainDiagramElement() {
- return (EReference)alternateCanvasEClass.getEStructuralFeatures().get(0);
+ return (EReference) alternateCanvasEClass.getEStructuralFeatures().get(0);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EReference getAlternateCanvas_AlternateTopLevelNodes() {
- return (EReference)alternateCanvasEClass.getEStructuralFeatures().get(1);
+ return (EReference) alternateCanvasEClass.getEStructuralFeatures().get(1);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EReference getAlternateCanvas_AlternateLinkNodes() {
- return (EReference)alternateCanvasEClass.getEStructuralFeatures().get(2);
+ return (EReference) alternateCanvasEClass.getEStructuralFeatures().get(2);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EReference getAlternateCanvas_Diagram() {
- return (EReference)alternateCanvasEClass.getEStructuralFeatures().get(3);
+ return (EReference) alternateCanvasEClass.getEStructuralFeatures().get(3);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EClass getAlternateGenTopLevelNode() {
@@ -404,26 +391,26 @@ public class PapyrusgmfgenextensionPackageImpl extends EPackageImpl implements P
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EReference getAlternateGenTopLevelNode_GenTopLevelNode() {
- return (EReference)alternateGenTopLevelNodeEClass.getEStructuralFeatures().get(0);
+ return (EReference) alternateGenTopLevelNodeEClass.getEStructuralFeatures().get(0);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EReference getAlternateGenTopLevelNode_TypeModelFacet() {
- return (EReference)alternateGenTopLevelNodeEClass.getEStructuralFeatures().get(1);
+ return (EReference) alternateGenTopLevelNodeEClass.getEStructuralFeatures().get(1);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EClass getAlternateGenLink() {
@@ -431,26 +418,26 @@ public class PapyrusgmfgenextensionPackageImpl extends EPackageImpl implements P
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EReference getAlternateGenLink_GenLinkNode() {
- return (EReference)alternateGenLinkEClass.getEStructuralFeatures().get(0);
+ return (EReference) alternateGenLinkEClass.getEStructuralFeatures().get(0);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EReference getAlternateGenLink_TypeModelFacet() {
- return (EReference)alternateGenLinkEClass.getEStructuralFeatures().get(1);
+ return (EReference) alternateGenLinkEClass.getEStructuralFeatures().get(1);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EClass getMutatingCanvas() {
@@ -458,17 +445,17 @@ public class PapyrusgmfgenextensionPackageImpl extends EPackageImpl implements P
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EReference getMutatingCanvas_AlternateCanvases() {
- return (EReference)mutatingCanvasEClass.getEStructuralFeatures().get(0);
+ return (EReference) mutatingCanvasEClass.getEStructuralFeatures().get(0);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EClass getOwnedEditpart() {
@@ -476,49 +463,48 @@ public class PapyrusgmfgenextensionPackageImpl extends EPackageImpl implements P
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public EAttribute getOwnedEditpart_Name() {
- return (EAttribute)ownedEditpartEClass.getEStructuralFeatures().get(0);
+ return (EAttribute) ownedEditpartEClass.getEStructuralFeatures().get(0);
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public PapyrusgmfgenextensionFactory getPapyrusgmfgenextensionFactory() {
- return (PapyrusgmfgenextensionFactory)getEFactoryInstance();
+ return (PapyrusgmfgenextensionFactory) getEFactoryInstance();
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
private boolean isCreated = false;
/**
- * Creates the meta-model objects for the package. This method is
- * guarded to have no affect on any invocation but its first.
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * Creates the meta-model objects for the package. This method is guarded to have no affect on any invocation but its first. <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public void createPackageContents() {
- if (isCreated) return;
+ if (isCreated)
+ return;
isCreated = true;
// Create classes and their features
- extendedGenNodeEClass = createEClass(EXTENDED_GEN_NODE);
- createEReference(extendedGenNodeEClass, EXTENDED_GEN_NODE__GEN_NODE);
- createEAttribute(extendedGenNodeEClass, EXTENDED_GEN_NODE__IS_ABSTRACT);
- createEReference(extendedGenNodeEClass, EXTENDED_GEN_NODE__SUPER_GEN_NODES);
- createEReference(extendedGenNodeEClass, EXTENDED_GEN_NODE__PROP_REFRESH_HOOK);
- createEAttribute(extendedGenNodeEClass, EXTENDED_GEN_NODE__NAME);
- createEAttribute(extendedGenNodeEClass, EXTENDED_GEN_NODE__SUPER_OWNED_EDIT_PART);
+ extendedGenViewEClass = createEClass(EXTENDED_GEN_VIEW);
+ createEReference(extendedGenViewEClass, EXTENDED_GEN_VIEW__GEN_VIEW);
+ createEAttribute(extendedGenViewEClass, EXTENDED_GEN_VIEW__IS_ABSTRACT);
+ createEReference(extendedGenViewEClass, EXTENDED_GEN_VIEW__SUPER_GEN_VIEWS);
+ createEReference(extendedGenViewEClass, EXTENDED_GEN_VIEW__PROP_REFRESH_HOOK);
+ createEAttribute(extendedGenViewEClass, EXTENDED_GEN_VIEW__NAME);
+ createEAttribute(extendedGenViewEClass, EXTENDED_GEN_VIEW__SUPER_OWNED_EDIT_PART);
commentedElementEClass = createEClass(COMMENTED_ELEMENT);
createEAttribute(commentedElementEClass, COMMENTED_ELEMENT__COMMENT);
@@ -558,21 +544,20 @@ public class PapyrusgmfgenextensionPackageImpl extends EPackageImpl implements P
}
/**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
private boolean isInitialized = false;
/**
- * Complete the initialization of the package and its meta-model. This
- * method is guarded to have no affect on any invocation but its first.
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
+ * Complete the initialization of the package and its meta-model. This method is guarded to have no affect on any invocation but its first. <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
* @generated
*/
public void initializePackageContents() {
- if (isInitialized) return;
+ if (isInitialized)
+ return;
isInitialized = true;
// Initialize package
@@ -581,16 +566,16 @@ public class PapyrusgmfgenextensionPackageImpl extends EPackageImpl implements P
setNsURI(eNS_URI);
// Obtain other dependent packages
- GMFGenPackage theGMFGenPackage = (GMFGenPackage)EPackage.Registry.INSTANCE.getEPackage(GMFGenPackage.eNS_URI);
- EcorePackage theEcorePackage = (EcorePackage)EPackage.Registry.INSTANCE.getEPackage(EcorePackage.eNS_URI);
- GenModelPackage theGenModelPackage = (GenModelPackage)EPackage.Registry.INSTANCE.getEPackage(GenModelPackage.eNS_URI);
+ GMFGenPackage theGMFGenPackage = (GMFGenPackage) EPackage.Registry.INSTANCE.getEPackage(GMFGenPackage.eNS_URI);
+ EcorePackage theEcorePackage = (EcorePackage) EPackage.Registry.INSTANCE.getEPackage(EcorePackage.eNS_URI);
+ GenModelPackage theGenModelPackage = (GenModelPackage) EPackage.Registry.INSTANCE.getEPackage(GenModelPackage.eNS_URI);
// Create type parameters
// Set bounds for type parameters
// Add supertypes to classes
- extendedGenNodeEClass.getESuperTypes().add(this.getCommentedElement());
+ extendedGenViewEClass.getESuperTypes().add(this.getCommentedElement());
propertyRefreshHookEClass.getESuperTypes().add(this.getExternalHook());
externalHookEClass.getESuperTypes().add(this.getCommentedElement());
specificLocatorEClass.getESuperTypes().add(this.getExternalHook());
@@ -602,52 +587,74 @@ public class PapyrusgmfgenextensionPackageImpl extends EPackageImpl implements P
ownedEditpartEClass.getESuperTypes().add(this.getExternalHook());
// Initialize classes and features; add operations and parameters
- initEClass(extendedGenNodeEClass, ExtendedGenNode.class, "ExtendedGenNode", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
- initEReference(getExtendedGenNode_GenNode(), theGMFGenPackage.getGenCommonBase(), null, "genNode", null, 1, -1, ExtendedGenNode.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_COMPOSITE, IS_RESOLVE_PROXIES, !IS_UNSETTABLE, !IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
- initEAttribute(getExtendedGenNode_IsAbstract(), ecorePackage.getEBoolean(), "isAbstract", null, 1, 1, ExtendedGenNode.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, !IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
- initEReference(getExtendedGenNode_SuperGenNodes(), theGMFGenPackage.getGenCommonBase(), null, "superGenNodes", null, 0, -1, ExtendedGenNode.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_COMPOSITE, IS_RESOLVE_PROXIES, !IS_UNSETTABLE, !IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
- initEReference(getExtendedGenNode_PropRefreshHook(), this.getPropertyRefreshHook(), null, "propRefreshHook", null, 0, 1, ExtendedGenNode.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, !IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
- initEAttribute(getExtendedGenNode_Name(), theEcorePackage.getEString(), "name", null, 0, 1, ExtendedGenNode.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
- initEAttribute(getExtendedGenNode_SuperOwnedEditPart(), theEcorePackage.getEString(), "superOwnedEditPart", null, 0, 1, ExtendedGenNode.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
+ initEClass(extendedGenViewEClass, ExtendedGenView.class, "ExtendedGenView", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
+ initEReference(getExtendedGenView_GenView(), theGMFGenPackage.getGenCommonBase(), null, "genView", null, 1, -1, ExtendedGenView.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE,
+ !IS_COMPOSITE, IS_RESOLVE_PROXIES, !IS_UNSETTABLE, !IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
+ initEAttribute(getExtendedGenView_IsAbstract(), ecorePackage.getEBoolean(), "isAbstract", null, 1, 1, ExtendedGenView.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE,
+ !IS_ID, !IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
+ initEReference(getExtendedGenView_SuperGenViews(), theGMFGenPackage.getGenCommonBase(), null, "superGenViews", null, 0, -1, ExtendedGenView.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE,
+ !IS_COMPOSITE, IS_RESOLVE_PROXIES, !IS_UNSETTABLE, !IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
+ initEReference(getExtendedGenView_PropRefreshHook(), this.getPropertyRefreshHook(), null, "propRefreshHook", null, 0, 1, ExtendedGenView.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE,
+ IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, !IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
+ initEAttribute(getExtendedGenView_Name(), theEcorePackage.getEString(), "name", null, 0, 1, ExtendedGenView.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID,
+ IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
+ initEAttribute(getExtendedGenView_SuperOwnedEditPart(), theEcorePackage.getEString(), "superOwnedEditPart", null, 0, 1, ExtendedGenView.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE,
+ !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEClass(commentedElementEClass, CommentedElement.class, "CommentedElement", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
- initEAttribute(getCommentedElement_Comment(), ecorePackage.getEString(), "comment", null, 1, 1, CommentedElement.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, !IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
+ initEAttribute(getCommentedElement_Comment(), ecorePackage.getEString(), "comment", null, 1, 1, CommentedElement.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID,
+ !IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
initEClass(propertyRefreshHookEClass, PropertyRefreshHook.class, "PropertyRefreshHook", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
- initEAttribute(getPropertyRefreshHook_TriggeringCondition(), ecorePackage.getEString(), "triggeringCondition", null, 1, 1, PropertyRefreshHook.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, !IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
- initEAttribute(getPropertyRefreshHook_Action(), ecorePackage.getEString(), "action", null, 1, 1, PropertyRefreshHook.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, !IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
+ initEAttribute(getPropertyRefreshHook_TriggeringCondition(), ecorePackage.getEString(), "triggeringCondition", null, 1, 1, PropertyRefreshHook.class, !IS_TRANSIENT, !IS_VOLATILE,
+ IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, !IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
+ initEAttribute(getPropertyRefreshHook_Action(), ecorePackage.getEString(), "action", null, 1, 1, PropertyRefreshHook.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID,
+ !IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
initEClass(externalHookEClass, ExternalHook.class, "ExternalHook", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
- initEAttribute(getExternalHook_Classpath(), ecorePackage.getEString(), "classpath", null, 0, 1, ExternalHook.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, !IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
+ initEAttribute(getExternalHook_Classpath(), ecorePackage.getEString(), "classpath", null, 0, 1, ExternalHook.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID,
+ !IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
initEClass(specificLocatorEClass, SpecificLocator.class, "SpecificLocator", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
- initEReference(getSpecificLocator_GenChildSideAffixedNode(), theGMFGenPackage.getGenChildSideAffixedNode(), null, "genChildSideAffixedNode", null, 0, 1, SpecificLocator.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_COMPOSITE, IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
+ initEReference(getSpecificLocator_GenChildSideAffixedNode(), theGMFGenPackage.getGenChildSideAffixedNode(), null, "genChildSideAffixedNode", null, 0, 1, SpecificLocator.class, !IS_TRANSIENT,
+ !IS_VOLATILE, IS_CHANGEABLE, !IS_COMPOSITE, IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEClass(papyrusExtensionRootNodeEClass, PapyrusExtensionRootNode.class, "PapyrusExtensionRootNode", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
- initEReference(getPapyrusExtensionRootNode_ExtensionNodes(), this.getCommentedElement(), null, "extensionNodes", null, 0, -1, PapyrusExtensionRootNode.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
+ initEReference(getPapyrusExtensionRootNode_ExtensionNodes(), this.getCommentedElement(), null, "extensionNodes", null, 0, -1, PapyrusExtensionRootNode.class, !IS_TRANSIENT, !IS_VOLATILE,
+ IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEClass(alternateCanvasEClass, AlternateCanvas.class, "AlternateCanvas", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
- initEReference(getAlternateCanvas_DomainDiagramElement(), theGenModelPackage.getGenClass(), null, "domainDiagramElement", null, 1, 1, AlternateCanvas.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_COMPOSITE, IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
- initEReference(getAlternateCanvas_AlternateTopLevelNodes(), this.getAlternateGenTopLevelNode(), null, "alternateTopLevelNodes", null, 0, -1, AlternateCanvas.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
- initEReference(getAlternateCanvas_AlternateLinkNodes(), this.getAlternateGenLink(), null, "alternateLinkNodes", null, 0, -1, AlternateCanvas.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
- initEReference(getAlternateCanvas_Diagram(), theGMFGenPackage.getGenDiagram(), null, "diagram", null, 1, 1, AlternateCanvas.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_COMPOSITE, IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
+ initEReference(getAlternateCanvas_DomainDiagramElement(), theGenModelPackage.getGenClass(), null, "domainDiagramElement", null, 1, 1, AlternateCanvas.class, !IS_TRANSIENT, !IS_VOLATILE,
+ IS_CHANGEABLE, !IS_COMPOSITE, IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
+ initEReference(getAlternateCanvas_AlternateTopLevelNodes(), this.getAlternateGenTopLevelNode(), null, "alternateTopLevelNodes", null, 0, -1, AlternateCanvas.class, !IS_TRANSIENT,
+ !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
+ initEReference(getAlternateCanvas_AlternateLinkNodes(), this.getAlternateGenLink(), null, "alternateLinkNodes", null, 0, -1, AlternateCanvas.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE,
+ IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
+ initEReference(getAlternateCanvas_Diagram(), theGMFGenPackage.getGenDiagram(), null, "diagram", null, 1, 1, AlternateCanvas.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_COMPOSITE,
+ IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEClass(alternateGenTopLevelNodeEClass, AlternateGenTopLevelNode.class, "AlternateGenTopLevelNode", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
- initEReference(getAlternateGenTopLevelNode_GenTopLevelNode(), theGMFGenPackage.getGenTopLevelNode(), null, "genTopLevelNode", null, 1, 1, AlternateGenTopLevelNode.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_COMPOSITE, IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
- initEReference(getAlternateGenTopLevelNode_TypeModelFacet(), theGMFGenPackage.getTypeModelFacet(), null, "typeModelFacet", null, 1, 1, AlternateGenTopLevelNode.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
+ initEReference(getAlternateGenTopLevelNode_GenTopLevelNode(), theGMFGenPackage.getGenTopLevelNode(), null, "genTopLevelNode", null, 1, 1, AlternateGenTopLevelNode.class, !IS_TRANSIENT,
+ !IS_VOLATILE, IS_CHANGEABLE, !IS_COMPOSITE, IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
+ initEReference(getAlternateGenTopLevelNode_TypeModelFacet(), theGMFGenPackage.getTypeModelFacet(), null, "typeModelFacet", null, 1, 1, AlternateGenTopLevelNode.class, !IS_TRANSIENT,
+ !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEClass(alternateGenLinkEClass, AlternateGenLink.class, "AlternateGenLink", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
- initEReference(getAlternateGenLink_GenLinkNode(), theGMFGenPackage.getGenLink(), null, "genLinkNode", null, 1, 1, AlternateGenLink.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_COMPOSITE, IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
- initEReference(getAlternateGenLink_TypeModelFacet(), theGMFGenPackage.getTypeModelFacet(), null, "typeModelFacet", null, 1, 1, AlternateGenLink.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
+ initEReference(getAlternateGenLink_GenLinkNode(), theGMFGenPackage.getGenLink(), null, "genLinkNode", null, 1, 1, AlternateGenLink.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE,
+ !IS_COMPOSITE, IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
+ initEReference(getAlternateGenLink_TypeModelFacet(), theGMFGenPackage.getTypeModelFacet(), null, "typeModelFacet", null, 1, 1, AlternateGenLink.class, !IS_TRANSIENT, !IS_VOLATILE,
+ IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEClass(mutatingCanvasEClass, MutatingCanvas.class, "MutatingCanvas", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
- initEReference(getMutatingCanvas_AlternateCanvases(), this.getAlternateCanvas(), null, "alternateCanvases", null, 0, -1, MutatingCanvas.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
+ initEReference(getMutatingCanvas_AlternateCanvases(), this.getAlternateCanvas(), null, "alternateCanvases", null, 0, -1, MutatingCanvas.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE,
+ IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEClass(ownedEditpartEClass, OwnedEditpart.class, "OwnedEditpart", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
- initEAttribute(getOwnedEditpart_Name(), theEcorePackage.getEString(), "name", null, 0, 1, OwnedEditpart.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
+ initEAttribute(getOwnedEditpart_Name(), theEcorePackage.getEString(), "name", null, 0, 1, OwnedEditpart.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE,
+ !IS_DERIVED, IS_ORDERED);
// Create resource
createResource(eNS_URI);
}
-} //PapyrusgmfgenextensionPackageImpl
+} // PapyrusgmfgenextensionPackageImpl
diff --git a/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/ExtendedGenNode.java b/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/ExtendedGenView.java
index c2481c6d323..3748885f665 100644
--- a/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/ExtendedGenNode.java
+++ b/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/ExtendedGenView.java
@@ -12,13 +12,13 @@ import org.eclipse.gmf.codegen.gmfgen.GenCommonBase;
/**
* <!-- begin-user-doc -->
* A representation of the model object '<em><b>Extended Gen Node</b></em>'.
* <!-- end-user-doc -->
*
* <!-- begin-model-doc -->
* This element is always linked to a genNode (topLevel, or child)
* Used set if an editPart is abstract.
* SuperGenNodes is a list of all superEditPart.
*
* Thanks to this, it is possible to factorize code and to decrease the number of generated classes.
* <!-- end-model-doc -->
@@ -26,35 +26,35 @@ import org.eclipse.gmf.codegen.gmfgen.GenCommonBase;
* <p>
* The following features are supported:
* <ul>
* <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getGenNode <em>Gen Node</em>}</li>
* <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#isIsAbstract <em>Is Abstract</em>}</li>
* <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getSuperGenNodes <em>Super Gen Nodes</em>}</li>
* <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getPropRefreshHook <em>Prop Refresh Hook</em>}</li>
* <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getName <em>Name</em>}</li>
* <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getSuperOwnedEditPart <em>Super Owned Edit Part</em>}</li>
* </ul>
* </p>
*
- * @see org.eclipse.papyrus.papyrusgmfgenextension.PapyrusgmfgenextensionPackage#getExtendedGenNode()
+ * @see org.eclipse.papyrus.papyrusgmfgenextension.PapyrusgmfgenextensionPackage#getExtendedGenView()
* @model
* @generated
*/
-public interface ExtendedGenNode extends CommentedElement {
+public interface ExtendedGenView extends CommentedElement {
/**
* Returns the value of the '<em><b>Gen Node</b></em>' reference list.
* The list contents are of type {@link org.eclipse.gmf.codegen.gmfgen.GenCommonBase}.
* <!-- begin-user-doc -->
* <p>
* If the meaning of the '<em>Gen Node</em>' reference list isn't clear,
* there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
* @return the value of the '<em>Gen Node</em>' reference list.
* @see org.eclipse.papyrus.papyrusgmfgenextension.PapyrusgmfgenextensionPackage#getExtendedGenNode_GenNode()
* @model required="true" ordered="false"
* @generated
*/
- EList<GenCommonBase> getGenNode();
+ EList<GenCommonBase> getGenView();
/**
* Returns the value of the '<em><b>Is Abstract</b></em>' attribute.
@@ -66,14 +66,14 @@ public interface ExtendedGenNode extends CommentedElement {
* <!-- end-user-doc -->
* @return the value of the '<em>Is Abstract</em>' attribute.
* @see #setIsAbstract(boolean)
- * @see org.eclipse.papyrus.papyrusgmfgenextension.PapyrusgmfgenextensionPackage#getExtendedGenNode_IsAbstract()
+ * @see org.eclipse.papyrus.papyrusgmfgenextension.PapyrusgmfgenextensionPackage#getExtendedGenView_IsAbstract()
* @model unique="false" required="true" ordered="false"
* @generated
*/
boolean isIsAbstract();
/**
* Sets the value of the '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#isIsAbstract <em>Is Abstract</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Is Abstract</em>' attribute.
@@ -83,20 +83,20 @@ public interface ExtendedGenNode extends CommentedElement {
void setIsAbstract(boolean value);
/**
* Returns the value of the '<em><b>Super Gen Nodes</b></em>' reference list.
* The list contents are of type {@link org.eclipse.gmf.codegen.gmfgen.GenCommonBase}.
* <!-- begin-user-doc -->
* <p>
* If the meaning of the '<em>Super Gen Nodes</em>' reference list isn't clear,
* there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
* @return the value of the '<em>Super Gen Nodes</em>' reference list.
* @see org.eclipse.papyrus.papyrusgmfgenextension.PapyrusgmfgenextensionPackage#getExtendedGenNode_SuperGenNodes()
* @model ordered="false"
* @generated
*/
- EList<GenCommonBase> getSuperGenNodes();
+ EList<GenCommonBase> getSuperGenViews();
/**
* Returns the value of the '<em><b>Prop Refresh Hook</b></em>' containment reference.
@@ -108,14 +108,14 @@ public interface ExtendedGenNode extends CommentedElement {
* <!-- end-user-doc -->
* @return the value of the '<em>Prop Refresh Hook</em>' containment reference.
* @see #setPropRefreshHook(PropertyRefreshHook)
- * @see org.eclipse.papyrus.papyrusgmfgenextension.PapyrusgmfgenextensionPackage#getExtendedGenNode_PropRefreshHook()
+ * @see org.eclipse.papyrus.papyrusgmfgenextension.PapyrusgmfgenextensionPackage#getExtendedGenView_PropRefreshHook()
* @model containment="true" ordered="false"
* @generated
*/
PropertyRefreshHook getPropRefreshHook();
/**
* Sets the value of the '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getPropRefreshHook <em>Prop Refresh Hook</em>}' containment reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Prop Refresh Hook</em>' containment reference.
@@ -134,14 +134,14 @@ public interface ExtendedGenNode extends CommentedElement {
* <!-- end-user-doc -->
* @return the value of the '<em>Name</em>' attribute.
* @see #setName(String)
- * @see org.eclipse.papyrus.papyrusgmfgenextension.PapyrusgmfgenextensionPackage#getExtendedGenNode_Name()
+ * @see org.eclipse.papyrus.papyrusgmfgenextension.PapyrusgmfgenextensionPackage#getExtendedGenView_Name()
* @model
* @generated
*/
String getName();
/**
* Sets the value of the '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getName <em>Name</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Name</em>' attribute.
@@ -160,14 +160,14 @@ public interface ExtendedGenNode extends CommentedElement {
* <!-- end-user-doc -->
* @return the value of the '<em>Super Owned Edit Part</em>' attribute.
* @see #setSuperOwnedEditPart(String)
- * @see org.eclipse.papyrus.papyrusgmfgenextension.PapyrusgmfgenextensionPackage#getExtendedGenNode_SuperOwnedEditPart()
+ * @see org.eclipse.papyrus.papyrusgmfgenextension.PapyrusgmfgenextensionPackage#getExtendedGenView_SuperOwnedEditPart()
* @model
* @generated
*/
String getSuperOwnedEditPart();
/**
* Sets the value of the '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getSuperOwnedEditPart <em>Super Owned Edit Part</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Super Owned Edit Part</em>' attribute.
@@ -176,4 +176,4 @@ public interface ExtendedGenNode extends CommentedElement {
*/
void setSuperOwnedEditPart(String value);
-} // ExtendedGenNode
+} // ExtendedGenView
@@ -12,13 +12,13 @@ import org.eclipse.gmf.codegen.gmfgen.GenCommonBase;
/**
* <!-- begin-user-doc -->
- * A representation of the model object '<em><b>Extended Gen Node</b></em>'.
+ * A representation of the model object '<em><b>Extended Gen View</b></em>'.
* <!-- end-user-doc -->
*
@@ -12,13 +12,13 @@ import org.eclipse.gmf.codegen.gmfgen.GenCommonBase;
*
* <!-- begin-model-doc -->
- * This element is always linked to a genNode (topLevel, or child)
+ * This element is always linked to a genView (topLevel, or child)
* Used set if an editPart is abstract.
@@ -12,13 +12,13 @@ import org.eclipse.gmf.codegen.gmfgen.GenCommonBase;
* Used set if an editPart is abstract.
- * SuperGenNodes is a list of all superEditPart.
+ * SuperGenViews is a list of all superEditPart.
*
* Thanks to this, it is possible to factorize code and to decrease the number of generated classes.
@@ -26,35 +26,35 @@ import org.eclipse.gmf.codegen.gmfgen.GenCommonBase;
* The following features are supported:
* <ul>
- * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getGenNode <em>Gen Node</em>}</li>
- * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#isIsAbstract <em>Is Abstract</em>}</li>
- * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getSuperGenNodes <em>Super Gen Nodes</em>}</li>
- * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getPropRefreshHook <em>Prop Refresh Hook</em>}</li>
- * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getName <em>Name</em>}</li>
- * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getSuperOwnedEditPart <em>Super Owned Edit Part</em>}</li>
+ * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView#getGenView <em>Gen View</em>}</li>
+ * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView#isIsAbstract <em>Is Abstract</em>}</li>
+ * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView#getSuperGenViews <em>Super Gen Views</em>}</li>
+ * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView#getPropRefreshHook <em>Prop Refresh Hook</em>}</li>
+ * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView#getName <em>Name</em>}</li>
+ * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView#getSuperOwnedEditPart <em>Super Owned Edit Part</em>}</li>
* </ul>
* </p>
@@ -26,35 +26,35 @@ import org.eclipse.gmf.codegen.gmfgen.GenCommonBase;
/**
- * Returns the value of the '<em><b>Gen Node</b></em>' reference list.
+ * Returns the value of the '<em><b>Gen View</b></em>' reference list.
* The list contents are of type {@link org.eclipse.gmf.codegen.gmfgen.GenCommonBase}.
* <!-- begin-user-doc -->
@@ -26,35 +26,35 @@ import org.eclipse.gmf.codegen.gmfgen.GenCommonBase;
* <!-- begin-user-doc -->
* <p>
- * If the meaning of the '<em>Gen Node</em>' reference list isn't clear,
+ * If the meaning of the '<em>Gen View</em>' reference list isn't clear,
* there really should be more of a description here...
* </p>
@@ -26,35 +26,35 @@ import org.eclipse.gmf.codegen.gmfgen.GenCommonBase;
* </p>
* <!-- end-user-doc -->
- * @return the value of the '<em>Gen Node</em>' reference list.
- * @see org.eclipse.papyrus.papyrusgmfgenextension.PapyrusgmfgenextensionPackage#getExtendedGenNode_GenNode()
+ * @return the value of the '<em>Gen View</em>' reference list.
+ * @see org.eclipse.papyrus.papyrusgmfgenextension.PapyrusgmfgenextensionPackage#getExtendedGenView_GenView()
* @model required="true" ordered="false"
* @generated
@@ -66,14 +66,14 @@ public interface ExtendedGenNode extends CommentedElement {
boolean isIsAbstract();
/**
- * Sets the value of the '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#isIsAbstract <em>Is Abstract</em>}' attribute.
+ * Sets the value of the '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView#isIsAbstract <em>Is Abstract</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -83,20 +83,20 @@ public interface ExtendedGenNode extends CommentedElement {
void setIsAbstract(boolean value);
/**
- * Returns the value of the '<em><b>Super Gen Nodes</b></em>' reference list.
+ * Returns the value of the '<em><b>Super Gen Views</b></em>' reference list.
* The list contents are of type {@link org.eclipse.gmf.codegen.gmfgen.GenCommonBase}.
* <!-- begin-user-doc -->
@@ -83,20 +83,20 @@ public interface ExtendedGenNode extends CommentedElement {
* <!-- begin-user-doc -->
* <p>
- * If the meaning of the '<em>Super Gen Nodes</em>' reference list isn't clear,
+ * If the meaning of the '<em>Super Gen Views</em>' reference list isn't clear,
* there really should be more of a description here...
* </p>
@@ -83,20 +83,20 @@ public interface ExtendedGenNode extends CommentedElement {
* </p>
* <!-- end-user-doc -->
- * @return the value of the '<em>Super Gen Nodes</em>' reference list.
- * @see org.eclipse.papyrus.papyrusgmfgenextension.PapyrusgmfgenextensionPackage#getExtendedGenNode_SuperGenNodes()
+ * @return the value of the '<em>Super Gen Views</em>' reference list.
+ * @see org.eclipse.papyrus.papyrusgmfgenextension.PapyrusgmfgenextensionPackage#getExtendedGenView_SuperGenViews()
* @model ordered="false"
* @generated
@@ -108,14 +108,14 @@ public interface ExtendedGenNode extends CommentedElement {
PropertyRefreshHook getPropRefreshHook();
/**
- * Sets the value of the '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getPropRefreshHook <em>Prop Refresh Hook</em>}' containment reference.
+ * Sets the value of the '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView#getPropRefreshHook <em>Prop Refresh Hook</em>}' containment reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -134,14 +134,14 @@ public interface ExtendedGenNode extends CommentedElement {
String getName();
/**
- * Sets the value of the '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getName <em>Name</em>}' attribute.
+ * Sets the value of the '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView#getName <em>Name</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -160,14 +160,14 @@ public interface ExtendedGenNode extends CommentedElement {
String getSuperOwnedEditPart();
/**
- * Sets the value of the '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getSuperOwnedEditPart <em>Super Owned Edit Part</em>}' attribute.
+ * Sets the value of the '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView#getSuperOwnedEditPart <em>Super Owned Edit Part</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
diff --git a/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/PapyrusgmfgenextensionFactory.java b/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/PapyrusgmfgenextensionFactory.java
index 9dd4270d877..41253d362c4 100644
--- a/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/PapyrusgmfgenextensionFactory.java
+++ b/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/PapyrusgmfgenextensionFactory.java
@@ -26,13 +26,13 @@ public interface PapyrusgmfgenextensionFactory extends EFactory {
PapyrusgmfgenextensionFactory eINSTANCE = org.eclipse.papyrus.papyrusgmfgenextension.impl.PapyrusgmfgenextensionFactoryImpl.init();
/**
* Returns a new object of class '<em>Extended Gen Node</em>'.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @return a new object of class '<em>Extended Gen Node</em>'.
* @generated
*/
- ExtendedGenNode createExtendedGenNode();
+ ExtendedGenView createExtendedGenView();
/**
* Returns a new object of class '<em>Commented Element</em>'.
@@ -26,13 +26,13 @@ public interface PapyrusgmfgenextensionFactory extends EFactory {
PapyrusgmfgenextensionFactory eINSTANCE = org.eclipse.papyrus.papyrusgmfgenextension.impl.PapyrusgmfgenextensionFactoryImpl.init();
/**
- * Returns a new object of class '<em>Extended Gen Node</em>'.
+ * Returns a new object of class '<em>Extended Gen View</em>'.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -26,13 +26,13 @@ public interface PapyrusgmfgenextensionFactory extends EFactory {
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @return a new object of class '<em>Extended Gen Node</em>'.
+ * @return a new object of class '<em>Extended Gen View</em>'.
* @generated
*/
diff --git a/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/PapyrusgmfgenextensionPackage.java b/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/PapyrusgmfgenextensionPackage.java
index f85162e6bb2..085f963ff1d 100644
--- a/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/PapyrusgmfgenextensionPackage.java
+++ b/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/PapyrusgmfgenextensionPackage.java
@@ -88,14 +88,14 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
int COMMENTED_ELEMENT_FEATURE_COUNT = 1;
/**
* The meta object id for the '{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenNodeImpl <em>Extended Gen Node</em>}' class.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @see org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenNodeImpl
- * @see org.eclipse.papyrus.papyrusgmfgenextension.impl.PapyrusgmfgenextensionPackageImpl#getExtendedGenNode()
+ * @see org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenViewImpl
+ * @see org.eclipse.papyrus.papyrusgmfgenextension.impl.PapyrusgmfgenextensionPackageImpl#getExtendedGenView()
* @generated
*/
- int EXTENDED_GEN_NODE = 0;
+ int EXTENDED_GEN_VIEW = 0;
/**
* The feature id for the '<em><b>Comment</b></em>' attribute.
@@ -104,16 +104,16 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
* @generated
* @ordered
*/
- int EXTENDED_GEN_NODE__COMMENT = COMMENTED_ELEMENT__COMMENT;
+ int EXTENDED_GEN_VIEW__COMMENT = COMMENTED_ELEMENT__COMMENT;
/**
* The feature id for the '<em><b>Gen Node</b></em>' reference list.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @generated
* @ordered
*/
- int EXTENDED_GEN_NODE__GEN_NODE = COMMENTED_ELEMENT_FEATURE_COUNT + 0;
+ int EXTENDED_GEN_VIEW__GEN_VIEW = COMMENTED_ELEMENT_FEATURE_COUNT + 0;
/**
* The feature id for the '<em><b>Is Abstract</b></em>' attribute.
@@ -122,16 +122,16 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
* @generated
* @ordered
*/
- int EXTENDED_GEN_NODE__IS_ABSTRACT = COMMENTED_ELEMENT_FEATURE_COUNT + 1;
+ int EXTENDED_GEN_VIEW__IS_ABSTRACT = COMMENTED_ELEMENT_FEATURE_COUNT + 1;
/**
* The feature id for the '<em><b>Super Gen Nodes</b></em>' reference list.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @generated
* @ordered
*/
- int EXTENDED_GEN_NODE__SUPER_GEN_NODES = COMMENTED_ELEMENT_FEATURE_COUNT + 2;
+ int EXTENDED_GEN_VIEW__SUPER_GEN_VIEWS = COMMENTED_ELEMENT_FEATURE_COUNT + 2;
/**
* The feature id for the '<em><b>Prop Refresh Hook</b></em>' containment reference.
@@ -140,7 +140,7 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
* @generated
* @ordered
*/
- int EXTENDED_GEN_NODE__PROP_REFRESH_HOOK = COMMENTED_ELEMENT_FEATURE_COUNT + 3;
+ int EXTENDED_GEN_VIEW__PROP_REFRESH_HOOK = COMMENTED_ELEMENT_FEATURE_COUNT + 3;
/**
* The feature id for the '<em><b>Name</b></em>' attribute.
@@ -149,7 +149,7 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
* @generated
* @ordered
*/
- int EXTENDED_GEN_NODE__NAME = COMMENTED_ELEMENT_FEATURE_COUNT + 4;
+ int EXTENDED_GEN_VIEW__NAME = COMMENTED_ELEMENT_FEATURE_COUNT + 4;
/**
* The feature id for the '<em><b>Super Owned Edit Part</b></em>' attribute.
@@ -158,16 +158,16 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
* @generated
* @ordered
*/
- int EXTENDED_GEN_NODE__SUPER_OWNED_EDIT_PART = COMMENTED_ELEMENT_FEATURE_COUNT + 5;
+ int EXTENDED_GEN_VIEW__SUPER_OWNED_EDIT_PART = COMMENTED_ELEMENT_FEATURE_COUNT + 5;
/**
* The number of structural features of the '<em>Extended Gen Node</em>' class.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @generated
* @ordered
*/
- int EXTENDED_GEN_NODE_FEATURE_COUNT = COMMENTED_ELEMENT_FEATURE_COUNT + 6;
+ int EXTENDED_GEN_VIEW_FEATURE_COUNT = COMMENTED_ELEMENT_FEATURE_COUNT + 6;
/**
* The meta object id for the '{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExternalHookImpl <em>External Hook</em>}' class.
@@ -586,80 +586,80 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
/**
* Returns the meta object for class '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode <em>Extended Gen Node</em>}'.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @return the meta object for class '<em>Extended Gen Node</em>'.
* @see org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode
* @generated
*/
- EClass getExtendedGenNode();
+ EClass getExtendedGenView();
/**
* Returns the meta object for the reference list '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getGenNode <em>Gen Node</em>}'.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @return the meta object for the reference list '<em>Gen Node</em>'.
* @see org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getGenNode()
* @see #getExtendedGenNode()
* @generated
*/
- EReference getExtendedGenNode_GenNode();
+ EReference getExtendedGenView_GenView();
/**
* Returns the meta object for the attribute '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#isIsAbstract <em>Is Abstract</em>}'.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @return the meta object for the attribute '<em>Is Abstract</em>'.
- * @see org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#isIsAbstract()
- * @see #getExtendedGenNode()
+ * @see org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView#isIsAbstract()
+ * @see #getExtendedGenView()
* @generated
*/
- EAttribute getExtendedGenNode_IsAbstract();
+ EAttribute getExtendedGenView_IsAbstract();
/**
* Returns the meta object for the reference list '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getSuperGenNodes <em>Super Gen Nodes</em>}'.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @return the meta object for the reference list '<em>Super Gen Nodes</em>'.
* @see org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getSuperGenNodes()
* @see #getExtendedGenNode()
* @generated
*/
- EReference getExtendedGenNode_SuperGenNodes();
+ EReference getExtendedGenView_SuperGenViews();
/**
* Returns the meta object for the containment reference '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getPropRefreshHook <em>Prop Refresh Hook</em>}'.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @return the meta object for the containment reference '<em>Prop Refresh Hook</em>'.
- * @see org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getPropRefreshHook()
- * @see #getExtendedGenNode()
+ * @see org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView#getPropRefreshHook()
+ * @see #getExtendedGenView()
* @generated
*/
- EReference getExtendedGenNode_PropRefreshHook();
+ EReference getExtendedGenView_PropRefreshHook();
/**
* Returns the meta object for the attribute '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getName <em>Name</em>}'.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @return the meta object for the attribute '<em>Name</em>'.
- * @see org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getName()
- * @see #getExtendedGenNode()
+ * @see org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView#getName()
+ * @see #getExtendedGenView()
* @generated
*/
- EAttribute getExtendedGenNode_Name();
+ EAttribute getExtendedGenView_Name();
/**
* Returns the meta object for the attribute '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getSuperOwnedEditPart <em>Super Owned Edit Part</em>}'.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @return the meta object for the attribute '<em>Super Owned Edit Part</em>'.
- * @see org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getSuperOwnedEditPart()
- * @see #getExtendedGenNode()
+ * @see org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView#getSuperOwnedEditPart()
+ * @see #getExtendedGenView()
* @generated
*/
- EAttribute getExtendedGenNode_SuperOwnedEditPart();
+ EAttribute getExtendedGenView_SuperOwnedEditPart();
/**
* Returns the meta object for class '{@link org.eclipse.papyrus.papyrusgmfgenextension.CommentedElement <em>Commented Element</em>}'.
@@ -960,22 +960,22 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
*/
interface Literals {
/**
* The meta object literal for the '{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenNodeImpl <em>Extended Gen Node</em>}' class.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @see org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenNodeImpl
- * @see org.eclipse.papyrus.papyrusgmfgenextension.impl.PapyrusgmfgenextensionPackageImpl#getExtendedGenNode()
+ * @see org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenViewImpl
+ * @see org.eclipse.papyrus.papyrusgmfgenextension.impl.PapyrusgmfgenextensionPackageImpl#getExtendedGenView()
* @generated
*/
- EClass EXTENDED_GEN_NODE = eINSTANCE.getExtendedGenNode();
+ EClass EXTENDED_GEN_VIEW = eINSTANCE.getExtendedGenView();
/**
* The meta object literal for the '<em><b>Gen Node</b></em>' reference list feature.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @generated
*/
- EReference EXTENDED_GEN_NODE__GEN_NODE = eINSTANCE.getExtendedGenNode_GenNode();
+ EReference EXTENDED_GEN_VIEW__GEN_VIEW = eINSTANCE.getExtendedGenView_GenView();
/**
* The meta object literal for the '<em><b>Is Abstract</b></em>' attribute feature.
@@ -983,15 +983,15 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
* <!-- end-user-doc -->
* @generated
*/
- EAttribute EXTENDED_GEN_NODE__IS_ABSTRACT = eINSTANCE.getExtendedGenNode_IsAbstract();
+ EAttribute EXTENDED_GEN_VIEW__IS_ABSTRACT = eINSTANCE.getExtendedGenView_IsAbstract();
/**
* The meta object literal for the '<em><b>Super Gen Nodes</b></em>' reference list feature.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @generated
*/
- EReference EXTENDED_GEN_NODE__SUPER_GEN_NODES = eINSTANCE.getExtendedGenNode_SuperGenNodes();
+ EReference EXTENDED_GEN_VIEW__SUPER_GEN_VIEWS = eINSTANCE.getExtendedGenView_SuperGenViews();
/**
* The meta object literal for the '<em><b>Prop Refresh Hook</b></em>' containment reference feature.
@@ -999,7 +999,7 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
* <!-- end-user-doc -->
* @generated
*/
- EReference EXTENDED_GEN_NODE__PROP_REFRESH_HOOK = eINSTANCE.getExtendedGenNode_PropRefreshHook();
+ EReference EXTENDED_GEN_VIEW__PROP_REFRESH_HOOK = eINSTANCE.getExtendedGenView_PropRefreshHook();
/**
* The meta object literal for the '<em><b>Name</b></em>' attribute feature.
@@ -1007,7 +1007,7 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
* <!-- end-user-doc -->
* @generated
*/
- EAttribute EXTENDED_GEN_NODE__NAME = eINSTANCE.getExtendedGenNode_Name();
+ EAttribute EXTENDED_GEN_VIEW__NAME = eINSTANCE.getExtendedGenView_Name();
/**
* The meta object literal for the '<em><b>Super Owned Edit Part</b></em>' attribute feature.
@@ -1015,7 +1015,7 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
* <!-- end-user-doc -->
* @generated
*/
- EAttribute EXTENDED_GEN_NODE__SUPER_OWNED_EDIT_PART = eINSTANCE.getExtendedGenNode_SuperOwnedEditPart();
+ EAttribute EXTENDED_GEN_VIEW__SUPER_OWNED_EDIT_PART = eINSTANCE.getExtendedGenView_SuperOwnedEditPart();
/**
* The meta object literal for the '{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.CommentedElementImpl <em>Commented Element</em>}' class.
@@ -88,14 +88,14 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
int COMMENTED_ELEMENT_FEATURE_COUNT = 1;
/**
- * The meta object id for the '{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenNodeImpl <em>Extended Gen Node</em>}' class.
+ * The meta object id for the '{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenViewImpl <em>Extended Gen View</em>}' class.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -104,16 +104,16 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
/**
- * The feature id for the '<em><b>Gen Node</b></em>' reference list.
+ * The feature id for the '<em><b>Gen View</b></em>' reference list.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -122,16 +122,16 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
/**
- * The feature id for the '<em><b>Super Gen Nodes</b></em>' reference list.
+ * The feature id for the '<em><b>Super Gen Views</b></em>' reference list.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -158,16 +158,16 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
/**
- * The number of structural features of the '<em>Extended Gen Node</em>' class.
+ * The number of structural features of the '<em>Extended Gen View</em>' class.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -586,80 +586,80 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
/**
- * Returns the meta object for class '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode <em>Extended Gen Node</em>}'.
+ * Returns the meta object for class '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView <em>Extended Gen View</em>}'.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -586,80 +586,80 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @return the meta object for class '<em>Extended Gen Node</em>'.
- * @see org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode
+ * @return the meta object for class '<em>Extended Gen View</em>'.
+ * @see org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView
* @generated
*/
@@ -586,80 +586,80 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
/**
- * Returns the meta object for the reference list '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getGenNode <em>Gen Node</em>}'.
+ * Returns the meta object for the reference list '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView#getGenView <em>Gen View</em>}'.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -586,80 +586,80 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @return the meta object for the reference list '<em>Gen Node</em>'.
- * @see org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getGenNode()
- * @see #getExtendedGenNode()
+ * @return the meta object for the reference list '<em>Gen View</em>'.
+ * @see org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView#getGenView()
+ * @see #getExtendedGenView()
* @generated
*/
@@ -586,80 +586,80 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
/**
- * Returns the meta object for the attribute '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#isIsAbstract <em>Is Abstract</em>}'.
+ * Returns the meta object for the attribute '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView#isIsAbstract <em>Is Abstract</em>}'.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -586,80 +586,80 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
/**
- * Returns the meta object for the reference list '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getSuperGenNodes <em>Super Gen Nodes</em>}'.
+ * Returns the meta object for the reference list '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView#getSuperGenViews <em>Super Gen Views</em>}'.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -586,80 +586,80 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @return the meta object for the reference list '<em>Super Gen Nodes</em>'.
- * @see org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getSuperGenNodes()
- * @see #getExtendedGenNode()
+ * @return the meta object for the reference list '<em>Super Gen Views</em>'.
+ * @see org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView#getSuperGenViews()
+ * @see #getExtendedGenView()
* @generated
*/
@@ -586,80 +586,80 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
/**
- * Returns the meta object for the containment reference '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getPropRefreshHook <em>Prop Refresh Hook</em>}'.
+ * Returns the meta object for the containment reference '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView#getPropRefreshHook <em>Prop Refresh Hook</em>}'.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -586,80 +586,80 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
/**
- * Returns the meta object for the attribute '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getName <em>Name</em>}'.
+ * Returns the meta object for the attribute '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView#getName <em>Name</em>}'.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -586,80 +586,80 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
/**
- * Returns the meta object for the attribute '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode#getSuperOwnedEditPart <em>Super Owned Edit Part</em>}'.
+ * Returns the meta object for the attribute '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView#getSuperOwnedEditPart <em>Super Owned Edit Part</em>}'.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -960,22 +960,22 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
interface Literals {
/**
- * The meta object literal for the '{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenNodeImpl <em>Extended Gen Node</em>}' class.
+ * The meta object literal for the '{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenViewImpl <em>Extended Gen View</em>}' class.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -960,22 +960,22 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
/**
- * The meta object literal for the '<em><b>Gen Node</b></em>' reference list feature.
+ * The meta object literal for the '<em><b>Gen View</b></em>' reference list feature.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -983,15 +983,15 @@ public interface PapyrusgmfgenextensionPackage extends EPackage {
/**
- * The meta object literal for the '<em><b>Super Gen Nodes</b></em>' reference list feature.
+ * The meta object literal for the '<em><b>Super Gen Views</b></em>' reference list feature.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
diff --git a/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/impl/ExtendedGenNodeImpl.java b/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/impl/ExtendedGenViewImpl.java
index 81bf859add7..0d24b46b8be 100644
--- a/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/impl/ExtendedGenNodeImpl.java
+++ b/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/impl/ExtendedGenViewImpl.java
@@ -22,39 +22,38 @@ import org.eclipse.emf.ecore.util.EObjectResolvingEList;
import org.eclipse.gmf.codegen.gmfgen.GenCommonBase;
-import org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode;
-import org.eclipse.papyrus.papyrusgmfgenextension.OwnedEditpart;
+import org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView;
import org.eclipse.papyrus.papyrusgmfgenextension.PapyrusgmfgenextensionPackage;
import org.eclipse.papyrus.papyrusgmfgenextension.PropertyRefreshHook;
/**
* <!-- begin-user-doc -->
* An implementation of the model object '<em><b>Extended Gen Node</b></em>'.
* <!-- end-user-doc -->
* <p>
* The following features are implemented:
* <ul>
* <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenNodeImpl#getGenNode <em>Gen Node</em>}</li>
* <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenNodeImpl#isIsAbstract <em>Is Abstract</em>}</li>
* <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenNodeImpl#getSuperGenNodes <em>Super Gen Nodes</em>}</li>
* <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenNodeImpl#getPropRefreshHook <em>Prop Refresh Hook</em>}</li>
* <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenNodeImpl#getName <em>Name</em>}</li>
* <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenNodeImpl#getSuperOwnedEditPart <em>Super Owned Edit Part</em>}</li>
* </ul>
* </p>
*
* @generated
*/
-public class ExtendedGenNodeImpl extends CommentedElementImpl implements ExtendedGenNode {
+public class ExtendedGenViewImpl extends CommentedElementImpl implements ExtendedGenView {
/**
* The cached value of the '{@link #getGenNode() <em>Gen Node</em>}' reference list.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @see #getGenNode()
+ * @see #getGenView()
* @generated
* @ordered
*/
- protected EList<GenCommonBase> genNode;
+ protected EList<GenCommonBase> genView;
/**
* The default value of the '{@link #isIsAbstract() <em>Is Abstract</em>}' attribute.
@@ -77,14 +76,14 @@ public class ExtendedGenNodeImpl extends CommentedElementImpl implements Extende
protected boolean isAbstract = IS_ABSTRACT_EDEFAULT;
/**
* The cached value of the '{@link #getSuperGenNodes() <em>Super Gen Nodes</em>}' reference list.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @see #getSuperGenNodes()
+ * @see #getSuperGenViews()
* @generated
* @ordered
*/
- protected EList<GenCommonBase> superGenNodes;
+ protected EList<GenCommonBase> superGenViews;
/**
* The cached value of the '{@link #getPropRefreshHook() <em>Prop Refresh Hook</em>}' containment reference.
@@ -141,7 +140,7 @@ public class ExtendedGenNodeImpl extends CommentedElementImpl implements Extende
* <!-- end-user-doc -->
* @generated
*/
- protected ExtendedGenNodeImpl() {
+ protected ExtendedGenViewImpl() {
super();
}
@@ -152,7 +151,7 @@ public class ExtendedGenNodeImpl extends CommentedElementImpl implements Extende
*/
@Override
protected EClass eStaticClass() {
- return PapyrusgmfgenextensionPackage.Literals.EXTENDED_GEN_NODE;
+ return PapyrusgmfgenextensionPackage.Literals.EXTENDED_GEN_VIEW;
}
/**
@@ -160,11 +159,11 @@ public class ExtendedGenNodeImpl extends CommentedElementImpl implements Extende
* <!-- end-user-doc -->
* @generated
*/
- public EList<GenCommonBase> getGenNode() {
- if (genNode == null) {
- genNode = new EObjectResolvingEList<GenCommonBase>(GenCommonBase.class, this, PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__GEN_NODE);
+ public EList<GenCommonBase> getGenView() {
+ if (genView == null) {
+ genView = new EObjectResolvingEList<GenCommonBase>(GenCommonBase.class, this, PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__GEN_VIEW);
}
- return genNode;
+ return genView;
}
/**
@@ -185,7 +184,7 @@ public class ExtendedGenNodeImpl extends CommentedElementImpl implements Extende
boolean oldIsAbstract = isAbstract;
isAbstract = newIsAbstract;
if (eNotificationRequired())
- eNotify(new ENotificationImpl(this, Notification.SET, PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__IS_ABSTRACT, oldIsAbstract, isAbstract));
+ eNotify(new ENotificationImpl(this, Notification.SET, PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__IS_ABSTRACT, oldIsAbstract, isAbstract));
}
/**
@@ -193,11 +192,11 @@ public class ExtendedGenNodeImpl extends CommentedElementImpl implements Extende
* <!-- end-user-doc -->
* @generated
*/
- public EList<GenCommonBase> getSuperGenNodes() {
- if (superGenNodes == null) {
- superGenNodes = new EObjectResolvingEList<GenCommonBase>(GenCommonBase.class, this, PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__SUPER_GEN_NODES);
+ public EList<GenCommonBase> getSuperGenViews() {
+ if (superGenViews == null) {
+ superGenViews = new EObjectResolvingEList<GenCommonBase>(GenCommonBase.class, this, PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__SUPER_GEN_VIEWS);
}
- return superGenNodes;
+ return superGenViews;
}
/**
@@ -218,7 +217,7 @@ public class ExtendedGenNodeImpl extends CommentedElementImpl implements Extende
PropertyRefreshHook oldPropRefreshHook = propRefreshHook;
propRefreshHook = newPropRefreshHook;
if (eNotificationRequired()) {
- ENotificationImpl notification = new ENotificationImpl(this, Notification.SET, PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__PROP_REFRESH_HOOK, oldPropRefreshHook, newPropRefreshHook);
+ ENotificationImpl notification = new ENotificationImpl(this, Notification.SET, PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__PROP_REFRESH_HOOK, oldPropRefreshHook, newPropRefreshHook);
if (msgs == null) msgs = notification; else msgs.add(notification);
}
return msgs;
@@ -233,14 +232,14 @@ public class ExtendedGenNodeImpl extends CommentedElementImpl implements Extende
if (newPropRefreshHook != propRefreshHook) {
NotificationChain msgs = null;
if (propRefreshHook != null)
- msgs = ((InternalEObject)propRefreshHook).eInverseRemove(this, EOPPOSITE_FEATURE_BASE - PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__PROP_REFRESH_HOOK, null, msgs);
+ msgs = ((InternalEObject)propRefreshHook).eInverseRemove(this, EOPPOSITE_FEATURE_BASE - PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__PROP_REFRESH_HOOK, null, msgs);
if (newPropRefreshHook != null)
- msgs = ((InternalEObject)newPropRefreshHook).eInverseAdd(this, EOPPOSITE_FEATURE_BASE - PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__PROP_REFRESH_HOOK, null, msgs);
+ msgs = ((InternalEObject)newPropRefreshHook).eInverseAdd(this, EOPPOSITE_FEATURE_BASE - PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__PROP_REFRESH_HOOK, null, msgs);
msgs = basicSetPropRefreshHook(newPropRefreshHook, msgs);
if (msgs != null) msgs.dispatch();
}
else if (eNotificationRequired())
- eNotify(new ENotificationImpl(this, Notification.SET, PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__PROP_REFRESH_HOOK, newPropRefreshHook, newPropRefreshHook));
+ eNotify(new ENotificationImpl(this, Notification.SET, PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__PROP_REFRESH_HOOK, newPropRefreshHook, newPropRefreshHook));
}
/**
@@ -261,7 +260,7 @@ public class ExtendedGenNodeImpl extends CommentedElementImpl implements Extende
String oldName = name;
name = newName;
if (eNotificationRequired())
- eNotify(new ENotificationImpl(this, Notification.SET, PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__NAME, oldName, name));
+ eNotify(new ENotificationImpl(this, Notification.SET, PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__NAME, oldName, name));
}
/**
@@ -282,7 +281,7 @@ public class ExtendedGenNodeImpl extends CommentedElementImpl implements Extende
String oldSuperOwnedEditPart = superOwnedEditPart;
superOwnedEditPart = newSuperOwnedEditPart;
if (eNotificationRequired())
- eNotify(new ENotificationImpl(this, Notification.SET, PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__SUPER_OWNED_EDIT_PART, oldSuperOwnedEditPart, superOwnedEditPart));
+ eNotify(new ENotificationImpl(this, Notification.SET, PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__SUPER_OWNED_EDIT_PART, oldSuperOwnedEditPart, superOwnedEditPart));
}
/**
@@ -293,7 +292,7 @@ public class ExtendedGenNodeImpl extends CommentedElementImpl implements Extende
@Override
public NotificationChain eInverseRemove(InternalEObject otherEnd, int featureID, NotificationChain msgs) {
switch (featureID) {
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__PROP_REFRESH_HOOK:
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__PROP_REFRESH_HOOK:
return basicSetPropRefreshHook(null, msgs);
}
return super.eInverseRemove(otherEnd, featureID, msgs);
@@ -307,17 +306,17 @@ public class ExtendedGenNodeImpl extends CommentedElementImpl implements Extende
@Override
public Object eGet(int featureID, boolean resolve, boolean coreType) {
switch (featureID) {
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__GEN_NODE:
- return getGenNode();
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__IS_ABSTRACT:
- return isIsAbstract() ? Boolean.TRUE : Boolean.FALSE;
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__SUPER_GEN_NODES:
- return getSuperGenNodes();
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__PROP_REFRESH_HOOK:
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__GEN_VIEW:
+ return getGenView();
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__IS_ABSTRACT:
+ return isIsAbstract();
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__SUPER_GEN_VIEWS:
+ return getSuperGenViews();
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__PROP_REFRESH_HOOK:
return getPropRefreshHook();
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__NAME:
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__NAME:
return getName();
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__SUPER_OWNED_EDIT_PART:
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__SUPER_OWNED_EDIT_PART:
return getSuperOwnedEditPart();
}
return super.eGet(featureID, resolve, coreType);
@@ -332,24 +331,24 @@ public class ExtendedGenNodeImpl extends CommentedElementImpl implements Extende
@Override
public void eSet(int featureID, Object newValue) {
switch (featureID) {
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__GEN_NODE:
- getGenNode().clear();
- getGenNode().addAll((Collection<? extends GenCommonBase>)newValue);
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__GEN_VIEW:
+ getGenView().clear();
+ getGenView().addAll((Collection<? extends GenCommonBase>)newValue);
return;
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__IS_ABSTRACT:
- setIsAbstract(((Boolean)newValue).booleanValue());
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__IS_ABSTRACT:
+ setIsAbstract((Boolean)newValue);
return;
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__SUPER_GEN_NODES:
- getSuperGenNodes().clear();
- getSuperGenNodes().addAll((Collection<? extends GenCommonBase>)newValue);
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__SUPER_GEN_VIEWS:
+ getSuperGenViews().clear();
+ getSuperGenViews().addAll((Collection<? extends GenCommonBase>)newValue);
return;
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__PROP_REFRESH_HOOK:
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__PROP_REFRESH_HOOK:
setPropRefreshHook((PropertyRefreshHook)newValue);
return;
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__NAME:
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__NAME:
setName((String)newValue);
return;
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__SUPER_OWNED_EDIT_PART:
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__SUPER_OWNED_EDIT_PART:
setSuperOwnedEditPart((String)newValue);
return;
}
@@ -364,22 +363,22 @@ public class ExtendedGenNodeImpl extends CommentedElementImpl implements Extende
@Override
public void eUnset(int featureID) {
switch (featureID) {
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__GEN_NODE:
- getGenNode().clear();
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__GEN_VIEW:
+ getGenView().clear();
return;
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__IS_ABSTRACT:
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__IS_ABSTRACT:
setIsAbstract(IS_ABSTRACT_EDEFAULT);
return;
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__SUPER_GEN_NODES:
- getSuperGenNodes().clear();
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__SUPER_GEN_VIEWS:
+ getSuperGenViews().clear();
return;
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__PROP_REFRESH_HOOK:
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__PROP_REFRESH_HOOK:
setPropRefreshHook((PropertyRefreshHook)null);
return;
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__NAME:
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__NAME:
setName(NAME_EDEFAULT);
return;
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__SUPER_OWNED_EDIT_PART:
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__SUPER_OWNED_EDIT_PART:
setSuperOwnedEditPart(SUPER_OWNED_EDIT_PART_EDEFAULT);
return;
}
@@ -394,17 +393,17 @@ public class ExtendedGenNodeImpl extends CommentedElementImpl implements Extende
@Override
public boolean eIsSet(int featureID) {
switch (featureID) {
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__GEN_NODE:
- return genNode != null && !genNode.isEmpty();
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__IS_ABSTRACT:
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__GEN_VIEW:
+ return genView != null && !genView.isEmpty();
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__IS_ABSTRACT:
return isAbstract != IS_ABSTRACT_EDEFAULT;
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__SUPER_GEN_NODES:
- return superGenNodes != null && !superGenNodes.isEmpty();
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__PROP_REFRESH_HOOK:
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__SUPER_GEN_VIEWS:
+ return superGenViews != null && !superGenViews.isEmpty();
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__PROP_REFRESH_HOOK:
return propRefreshHook != null;
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__NAME:
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__NAME:
return NAME_EDEFAULT == null ? name != null : !NAME_EDEFAULT.equals(name);
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE__SUPER_OWNED_EDIT_PART:
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW__SUPER_OWNED_EDIT_PART:
return SUPER_OWNED_EDIT_PART_EDEFAULT == null ? superOwnedEditPart != null : !SUPER_OWNED_EDIT_PART_EDEFAULT.equals(superOwnedEditPart);
}
return super.eIsSet(featureID);
@@ -430,4 +429,4 @@ public class ExtendedGenNodeImpl extends CommentedElementImpl implements Extende
return result.toString();
}
-} //ExtendedGenNodeImpl
+} //ExtendedGenViewImpl
@@ -22,39 +22,38 @@ import org.eclipse.emf.ecore.util.EObjectResolvingEList;
/**
* <!-- begin-user-doc -->
- * An implementation of the model object '<em><b>Extended Gen Node</b></em>'.
+ * An implementation of the model object '<em><b>Extended Gen View</b></em>'.
* <!-- end-user-doc -->
* <p>
@@ -22,39 +22,38 @@ import org.eclipse.emf.ecore.util.EObjectResolvingEList;
* The following features are implemented:
* <ul>
- * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenNodeImpl#getGenNode <em>Gen Node</em>}</li>
- * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenNodeImpl#isIsAbstract <em>Is Abstract</em>}</li>
- * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenNodeImpl#getSuperGenNodes <em>Super Gen Nodes</em>}</li>
- * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenNodeImpl#getPropRefreshHook <em>Prop Refresh Hook</em>}</li>
- * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenNodeImpl#getName <em>Name</em>}</li>
- * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenNodeImpl#getSuperOwnedEditPart <em>Super Owned Edit Part</em>}</li>
+ * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenViewImpl#getGenView <em>Gen View</em>}</li>
+ * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenViewImpl#isIsAbstract <em>Is Abstract</em>}</li>
+ * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenViewImpl#getSuperGenViews <em>Super Gen Views</em>}</li>
+ * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenViewImpl#getPropRefreshHook <em>Prop Refresh Hook</em>}</li>
+ * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenViewImpl#getName <em>Name</em>}</li>
+ * <li>{@link org.eclipse.papyrus.papyrusgmfgenextension.impl.ExtendedGenViewImpl#getSuperOwnedEditPart <em>Super Owned Edit Part</em>}</li>
* </ul>
* </p>
@@ -22,39 +22,38 @@ import org.eclipse.emf.ecore.util.EObjectResolvingEList;
/**
- * The cached value of the '{@link #getGenNode() <em>Gen Node</em>}' reference list.
+ * The cached value of the '{@link #getGenView() <em>Gen View</em>}' reference list.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -77,14 +76,14 @@ public class ExtendedGenNodeImpl extends CommentedElementImpl implements Extende
protected boolean isAbstract = IS_ABSTRACT_EDEFAULT;
/**
- * The cached value of the '{@link #getSuperGenNodes() <em>Super Gen Nodes</em>}' reference list.
+ * The cached value of the '{@link #getSuperGenViews() <em>Super Gen Views</em>}' reference list.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
diff --git a/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/util/PapyrusgmfgenextensionAdapterFactory.java b/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/util/PapyrusgmfgenextensionAdapterFactory.java
index 78faae0defb..d93a1841700 100644
--- a/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/util/PapyrusgmfgenextensionAdapterFactory.java
+++ b/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/util/PapyrusgmfgenextensionAdapterFactory.java
@@ -72,8 +72,8 @@ public class PapyrusgmfgenextensionAdapterFactory extends AdapterFactoryImpl {
protected PapyrusgmfgenextensionSwitch<Adapter> modelSwitch =
new PapyrusgmfgenextensionSwitch<Adapter>() {
@Override
- public Adapter caseExtendedGenNode(ExtendedGenNode object) {
- return createExtendedGenNodeAdapter();
+ public Adapter caseExtendedGenView(ExtendedGenView object) {
+ return createExtendedGenViewAdapter();
}
@Override
public Adapter caseCommentedElement(CommentedElement object) {
@@ -136,16 +136,16 @@ public class PapyrusgmfgenextensionAdapterFactory extends AdapterFactoryImpl {
/**
* Creates a new adapter for an object of class '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode <em>Extended Gen Node</em>}'.
* <!-- begin-user-doc -->
* This default implementation returns null so that we can easily ignore cases;
* it's useful to ignore a case when inheritance will catch all the cases anyway.
* <!-- end-user-doc -->
* @return the new adapter.
- * @see org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode
+ * @see org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView
* @generated
*/
- public Adapter createExtendedGenNodeAdapter() {
+ public Adapter createExtendedGenViewAdapter() {
return null;
}
@@ -136,16 +136,16 @@ public class PapyrusgmfgenextensionAdapterFactory extends AdapterFactoryImpl {
/**
- * Creates a new adapter for an object of class '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenNode <em>Extended Gen Node</em>}'.
+ * Creates a new adapter for an object of class '{@link org.eclipse.papyrus.papyrusgmfgenextension.ExtendedGenView <em>Extended Gen View</em>}'.
* <!-- begin-user-doc -->
* This default implementation returns null so that we can easily ignore cases;
diff --git a/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/util/PapyrusgmfgenextensionSwitch.java b/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/util/PapyrusgmfgenextensionSwitch.java
index 9fb6d7d040e..0c9ef4fc6bf 100644
--- a/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/util/PapyrusgmfgenextensionSwitch.java
+++ b/plugins/developer/org.eclipse.papyrus.gmfgenextension/src/org/eclipse/papyrus/papyrusgmfgenextension/util/PapyrusgmfgenextensionSwitch.java
@@ -87,10 +87,10 @@ public class PapyrusgmfgenextensionSwitch<T> {
*/
protected T doSwitch(int classifierID, EObject theEObject) {
switch (classifierID) {
- case PapyrusgmfgenextensionPackage.EXTENDED_GEN_NODE: {
- ExtendedGenNode extendedGenNode = (ExtendedGenNode)theEObject;
- T result = caseExtendedGenNode(extendedGenNode);
- if (result == null) result = caseCommentedElement(extendedGenNode);
+ case PapyrusgmfgenextensionPackage.EXTENDED_GEN_VIEW: {
+ ExtendedGenView extendedGenView = (ExtendedGenView)theEObject;
+ T result = caseExtendedGenView(extendedGenView);
+ if (result == null) result = caseCommentedElement(extendedGenView);
if (result == null) result = defaultCase(theEObject);
return result;
}
@@ -171,17 +171,17 @@ public class PapyrusgmfgenextensionSwitch<T> {
}
/**
* Returns the result of interpreting the object as an instance of '<em>Extended Gen Node</em>'.
* <!-- begin-user-doc -->
* This implementation returns null;
* returning a non-null result will terminate the switch.
* <!-- end-user-doc -->
* @param object the target of the switch.
* @return the result of interpreting the object as an instance of '<em>Extended Gen Node</em>'.
* @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
* @generated
*/
- public T caseExtendedGenNode(ExtendedGenNode object) {
+ public T caseExtendedGenView(ExtendedGenView object) {
return null;
}
@@ -171,17 +171,17 @@ public class PapyrusgmfgenextensionSwitch<T> {
}
/**
- * Returns the result of interpreting the object as an instance of '<em>Extended Gen Node</em>'.
+ * Returns the result of interpreting the object as an instance of '<em>Extended Gen View</em>'.
* <!-- begin-user-doc -->
* This implementation returns null;
@@ -171,17 +171,17 @@ public class PapyrusgmfgenextensionSwitch<T> {
* <!-- end-user-doc -->
* @param object the target of the switch.
- * @return the result of interpreting the object as an instance of '<em>Extended Gen Node</em>'.
+ * @return the result of interpreting the object as an instance of '<em>Extended Gen View</em>'.
* @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
* @generated

Back to the top